<?php

/**  // € // to identify files as UTF8
 * define backend comments like todo etc
 *
 * @module          backend_comment
 * @author          Wolfgang Studer
 * @copyright       2016 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.04.000 | 2016-12-17
 * @lepador_link    http://www.lepton-cms.com/lepador/modules/backend_comment.php
 * @forum_link      http://forum.lepton-cms.org/viewtopic.php?f=66&t=3059
*/


// include class.secure.php to protect this file and the whole CMS!
	if ( defined('LEPTON_PATH') == TRUE ):
		include(LEPTON_PATH.'/framework/class.secure.php');
	else:
		$oneback = "../";
		$root = $oneback;
		$level = 1;
		while (( $level < 10 ) && ( file_exists( $root . '/framework/class.secure.php' ) == FALSE )):
			$root .= $oneback;
			$level += 1;
		endwhile;
	
		if ( file_exists($root.'/framework/class.secure.php') == TRUE ):
			include( $root . '/framework/class.secure.php' );
		else:
			trigger_error( sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR );
		endif;
	endif;
// end include class.secure.php


/** ------------------------------------------------------------------------------------
 * build folder tree
 * @return	array		$tree		= result
 * @param	string		$root		= root folder to start onwards
 * @param	array		$tree		= available result so far
 * @param	string		$remove		= string to be removed from path
 * @param	string		$resultType	= trail ( path1, path1 / path1.1 )
 *									  level ( path1, -- path1.1, ---- path1.1.1 )
 * @param	string		$keyPrefix	= prefix string to be added before the tree key (= folder name)
 * @param	array		$comment_vars
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'comment_build_folder_tree' ) == FALSE ):
	function comment_build_folder_tree( $root = LEPTON_PATH, $tree = array(), $remove = '', $resultType = 'level', $keyPrefix = '', $comment_vars = array() )
	{
		// input root folder does not exists
		if ( is_dir( $root ) == FALSE ):
			return ( comment_finalize_folder_tree( $tree, $comment_vars ) );
		endif;

		// build folder array
		$folders = array();
		$path = realpath( $root );
		foreach ( new RecursiveIteratorIterator( new RecursiveDirectoryIterator( $path )) as $itemName ):
			if ( is_dir( $itemName ) == TRUE ):
				// remove input $remove
				$itemName = str_replace( $remove, '', $itemName );
				// process as nothing is to be excluded
				$itemName = $itemName;
				if ( strlen( $itemName ) > 0 ):
					$folders[] = rtrim( $itemName, '.' );
				endif;
			endif;
		endforeach;

		// no data found
		if ( count( $folders ) == 0 ):
			return ( comment_finalize_folder_tree( $tree, $comment_vars ) );
		endif;

		$foldersUnique = array_unique( $folders );
		asort( $foldersUnique );

		// prepare output
		foreach ( $foldersUnique as $folder ):
			// initialize prefix
			$prefix = "";

			// create layout
			if ( $resultType == 'trail' ):
				// use folder
				$lastFolder = $folder;

			elseif ( $resultType == 'level' ):
				// folder is "/xx/xx/" = 4 exploded elements
				$tmp = explode( DIRECTORY_SEPARATOR, $folder );
				if ( count( $tmp ) > 2 ):
					$prefix = str_repeat( '--', count( $tmp ) - 2 ) . ' ';

					$lastFolder = array_pop( $tmp );	// last element is empty
					$lastFolder = array_pop( $tmp );
				else:
					// use folder
					$lastFolder = $folder;
				endif;

			else:
				// customer specific layout
				$content = comment_get_folder_layout( $folder, $comment_vars );
			endif;
			$tree[ $keyPrefix . $folder ] = $prefix . $lastFolder;
		endforeach;

		// return the tree
		return ( comment_finalize_folder_tree( $tree, $comment_vars ) );
	}
endif;


/** ------------------------------------------------------------------------------------
 * complete foldertree
 * @return	array		$tree
 * @param	array		$tree
 * @param	array		$comment_vars
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'comment_finalize_folder_tree' ) == FALSE ):
	function comment_finalize_folder_tree( $tree, $comment_vars )
	{
		// overwrite globals with passed vars
		// needed in frontend when some vars are not properly handled by global
		if (( count( $comment_vars ) > 0 )
		and ( array_key_exists( 'MOD_BACKEND_COMMENT', $comment_vars ) == TRUE )):
			$MOD_BACKEND_COMMENT = $comment_vars[ 'MOD_BACKEND_COMMENT' ];
		endif;

		// data available
		if (( count( $tree ) > 0 )
		and ( array_key_exists( 'folder', $MOD_BACKEND_COMMENT ) == TRUE )):
			// !! Do not use array_merge as it does not preserve numeric key values
			// which might be the case if keyPrefix is '' !!!
			$tree = array( '0' => $MOD_BACKEND_COMMENT['folder'] ) + $tree;
		elseif ( array_key_exists( 'nofolder', $MOD_BACKEND_COMMENT ) == TRUE ):
			$tree[''] = $MOD_BACKEND_COMMENT['nofolder'];
		endif;

		// return the tree
		return($tree);
	}
endif;


/** ------------------------------------------------------------------------------------
 * set layout for page tree line
 * @return	array		$folder
 * @param	array		$folder
 * @param	array		$comment_vars
 *
 * Note: This is done in a separate function in order that just this function can be replaced if wanted
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'comment_get_folder_layout' ) == FALSE ):
	function comment_get_folder_layout( $folder, $comment_vars )
	{
		return $folder;
	}
endif;

?>
